@@ -1,5 +1,6 @@
 import logging
 from IPython.core.display import display, HTML
+from expai.utils import generate_response
 
 class ExpaiModelExplainer:
     def __init__(self, model_id: str, project_id: str, api_key: str, headers: dict, server_name: str, session, project):
@@ -45,12 +46,7 @@ class ExpaiModelExplainer:
         response = self.sess.request("GET",
                                     self.server_name + "/api/explain/{}".format(self.model_id), headers=self.headers, json=json)
 
-        if response.ok:
-            return response.json()['shap_values']
-        else:
-            logging.error("There was an error creating the explanation. Please, check the details below and report them to EXPAI if required. \n {}".format(
-                response.json()['message']))
-            return None
+        return response.json()
 
     def explain_model(self, sample_name: str = None, sample_id: str = None, indexes: list = None, shap: bool = True, lime: bool = False):
         assert sample_name is not None or sample_id is not None, "You must provide a sample name or id for the explanation"
@@ -75,12 +71,7 @@ class ExpaiModelExplainer:
         response = self.sess.request("GET",
                                     self.server_name + "/api/explain/{}/graphics".format(self.model_id), headers=self.headers, json=json)
 
-        if response.ok:
-            return response.json()['visualizations']
-        else:
-            logging.error("There was an error creating the explanation. Please, check the details below and report them to EXPAI if required. \n {}".format(
-                response.json()['message']))
-            return None
+        return response.json()
 
     def explain_sample(self, sample_name: str = None, sample_id: str = None, index: list = None, shap: bool = True, lime: bool = False):
         assert sample_name is not None or sample_id is not None, "You must provide a sample name or id for the explanation"
@@ -105,10 +96,14 @@ class ExpaiModelExplainer:
                                     self.server_name + "/api/explain/{}/sample/graphics".format(self.model_id), headers=self.headers, json=json)
 
         if response.ok:
-            return response.json()['visualizations']['single_force_plot']
+            return response.json().json()['visualizations']['single_force_plot']
         else:
-            logging.error("There was an error creating the explanation. Please, check the details below and report them to EXPAI if required. \n {}".format(
-                response.json()['message']))
+            if 'error' in response.json().keys():
+                logging.error("There was an error deleting the sample. Please, check the details below. \n {}".format(
+                    response.json()['error']))
+            else:
+                logging.error("There was an error deleting the sample. Please, check the details below. \n {}".format(
+                    response.json()['message']))
             return None
 
 
@@ -123,22 +118,30 @@ class ExpaiModelExplainer:
         with open(filepath, 'r') as f:
             return f.read()
 
-    def what_if(self, old_sample: dict = None, new_sample: dict = None):
-        assert old_sample is not None and new_sample is not None, "You must provide an old and new sample to use this module"
+    def what_if(self, original_sample: dict = None, modified_sample: dict = None, original_sample_display: dict = None, modified_sample_display: dict = None):
+        assert original_sample is not None and modified_sample is not None, "You must provide an old and new sample to use this module"
+        if original_sample_display is not None or modified_sample_display is not None:
+            assert original_sample_display is not None and modified_sample_display is not None, "You must provide both display samples."
 
         json = {
-            "old_sample": old_sample,
-            "new_sample": new_sample
+            "original_sample": original_sample,
+            "modified_sample": modified_sample,
+            "original_sample_display": original_sample_display,
+            "modified_sample_display": modified_sample_display,
         }
 
         response = self.sess.request("GET",
-                                    self.server_name + "/api/explain/{}/sample/graphics".format(self.model_id), headers=self.headers, json=json)
+                                    self.server_name + "/api/explain/{}/what_if".format(self.model_id), headers=self.headers, json=json)
 
         if response.ok:
-            return response.json()['visualizations']['single_force_plot']
+            return response.json()['visualizations'], response.json()['shap_values']
         else:
-            logging.error("There was an error creating the explanation. Please, check the details below and report them to EXPAI if required. \n {}".format(
-                response.json()['message']))
+            if 'error' in response.json().keys():
+                logging.error("There was an error generating what if explanation. Please, check the details below. \n {}".format(
+                    response.json()['error']))
+            else:
+                logging.error("There was an error generating what if explanation. Please, check the details below. \n {}".format(
+                    response.json()['message']))
             return None
 
 
