@@ -1,6 +1,7 @@
 import requests
 import logging
 from expai.expai_project import ExpaiProject
+from expai.utils import generate_response
 
 
 class ExpaiLogin:
@@ -29,18 +30,37 @@ class ExpaiLogin:
         if not response.ok:
             logging.error("Invalid credentials, please check them and try again. Thank you.")
 
-    def project_list(self):
+    def project_list(self, search_by: str = None, exact_search: str = None):
         """
         Returns the list of projects for the user
         :return: list of projects
         """
-        response = self.sess.request("GET", self.server_name + "/api/projects/list", headers=self.headers)
-        if response.ok:
-            return response.json()['projects']
-        else:
-            logging.error("There was an error listing your projects.")
+
+        if exact_search is not None:
+            response = self.sess.request("GET",
+                                         self.server_name + "/api/projects/list/contains/{}".format(exact_search),
+                                         headers=self.headers)
+
+            if 'projects' in response.json().keys():
+                for project in response.json()['projects']:
+                    if project['project_name_des'] == exact_search:
+                        return project
+            logging.error(
+                "We could not find a sample with this exact name. Try again or consider using search_by parameter to find similar samples")
             return None
 
+        elif search_by is not None:
+            response = self.sess.request("GET",
+                                         self.server_name + "/api/projects/list/contains/{}".format(search_by),
+                                         headers=self.headers)
+            return generate_response(response, 'samples')
+
+        else:
+            response = self.sess.request("GET", self.server_name + "/api/projects/list", headers=self.headers)
+
+            return generate_response(response, 'projects')
+
+
     def search_project(self, search_by: str = None):
         """
         Search all projects containing a term
@@ -51,12 +71,7 @@ class ExpaiLogin:
 
         response = self.sess.request("GET", self.server_name + "/api/projects/list/contains/{}".format(search_by),
                                      headers=self.headers)
-        if response.ok:
-            return response.json()['projects']
-        else:
-            logging.error("There was an error searching the project. Please, check the details below. \n {}".format(
-                response.json()['message']))
-            return None
+        return generate_response(response, 'projects')
 
     def create_project(self, project_name: str = None):
         """
@@ -71,11 +86,9 @@ class ExpaiLogin:
                                      json=payload)
 
         if response.ok:
-            return True
+            return "Project successfully created with id: {}".format(response.json()['project_id'])
         else:
-            logging.error("There was an error creating the project. Please, check the details below. \n {}".format(
-                response.json()['message']))
-            return None
+            return generate_response(response)
 
     def delete_project(self, project_name: str = None, project_id: str = None):
         """
@@ -93,11 +106,9 @@ class ExpaiLogin:
                                      headers=self.headers)
 
         if response.ok:
-            return True
+            return "Project successfully deleted"
         else:
-            logging.error("There was an error deleting the project. Please, check the details below. \n {}".format(
-                response.json()['message']))
-            return None
+            return generate_response(response)
 
     def get_project(self, project_name: str = None, project_id: str = None):
         """
